@@ -1,6 +1,6 @@
 import importlib
 from types import ModuleType
-from typing import Any, Union
+from typing import Any
 
 import pytest
 from sqlmodel import create_engine
@@ -8,7 +8,7 @@ from sqlmodel import create_engine
 from ...conftest import PrintMock, needs_py310
 
 
-def check_calls(calls: list[list[Union[str, dict[str, Any]]]]):
+def check_calls(calls: list[list[str | dict[str, Any]]]):
     assert calls[0][0] == [
         {
             "name": "Deadpond",
@@ -42,7 +42,6 @@ def get_module(request: pytest.FixtureRequest) -> ModuleType:
 @pytest.mark.parametrize(
     "module",
     [
-        pytest.param("tutorial003_py39"),
         pytest.param("tutorial003_py310", marks=needs_py310),
     ],
     indirect=True,
@@ -55,7 +54,6 @@ def test_tutorial_003(print_mock: PrintMock, module: ModuleType):
 @pytest.mark.parametrize(
     "module",
     [
-        pytest.param("tutorial004_py39"),
         pytest.param("tutorial004_py310", marks=needs_py310),
     ],
     indirect=True,
